==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/SimpleWorkflow/WorkflowExecution.pm <==
package Paws::SimpleWorkflow::WorkflowExecution;
  use Moose;
  has RunId => (is => 'ro', isa => 'Str', request_name => 'runId', traits => ['NameInRequest'], required => 1);
  has WorkflowId => (is => 'ro', isa => 'Str', request_name => 'workflowId', traits => ['NameInRequest'], required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::SimpleWorkflow::WorkflowExecution

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SimpleWorkflow::WorkflowExecution object:

  $service_obj->Method(Att1 => { RunId => $value, ..., WorkflowId => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SimpleWorkflow::WorkflowExecution object:

  $result = $service_obj->Method(...);
  $result->Att1->RunId

=head1 DESCRIPTION

Represents a workflow execution.

=head1 ATTRIBUTES


=head2 B<REQUIRED> RunId => Str

  A system-generated unique identifier for the workflow execution.


=head2 B<REQUIRED> WorkflowId => Str

  The user defined identifier associated with the workflow execution.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SimpleWorkflow>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/SimpleWorkflow/WorkflowExecution.pm <==
package Paws::SimpleWorkflow::WorkflowExecution;
  use Moose;
  has RunId => (is => 'ro', isa => 'Str', request_name => 'runId', traits => ['NameInRequest'], required => 1);
  has WorkflowId => (is => 'ro', isa => 'Str', request_name => 'workflowId', traits => ['NameInRequest'], required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::SimpleWorkflow::WorkflowExecution

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::SimpleWorkflow::WorkflowExecution object:

  $service_obj->Method(Att1 => { RunId => $value, ..., WorkflowId => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::SimpleWorkflow::WorkflowExecution object:

  $result = $service_obj->Method(...);
  $result->Att1->RunId

=head1 DESCRIPTION

Represents a workflow execution.

=head1 ATTRIBUTES


=head2 B<REQUIRED> RunId => Str

  A system-generated unique identifier for the workflow execution.


=head2 B<REQUIRED> WorkflowId => Str

  The user defined identifier associated with the workflow execution.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::SimpleWorkflow>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
